@@ -4,5 +4,5 @@ sudo systemctl stop irqbalance.service
 
 for i in $(ls /proc/irq/*/smp_affinity)
 do
-    echo  33 | sudo tee $i
+    echo  e38 | sudo tee $i
 done
