@@ -1,11 +1,11 @@
-use anyhow::{bail, ensure, Result};
-
-use crate::runtime::buffer::pagesize;
-use crate::runtime::config;
 use std::ffi::CString;
 use std::os::unix::ffi::OsStrExt;
 use std::path::PathBuf;
 
+use crate::anyhow::{bail, ensure, Result};
+use crate::runtime::buffer::pagesize;
+use crate::runtime::config;
+
 #[derive(Debug)]
 pub struct DoubleMappedTempFile {
     addr: *mut libc::c_void,
@@ -46,7 +46,7 @@ impl DoubleMappedTempFile {
             fd = libc::mkstemp(path as *mut libc::c_char);
             ensure!(fd >= 0, "tempfile could not be created");
 
-            let ret = libc::unlink(path.cast::<i8>());
+            let ret = libc::unlink(path.cast::<libc::c_char>());
             if ret < 0 {
                 libc::close(fd);
                 bail!("unlinking failed");
